
Django 3rd party module crash course
====================================

This directory holds the complete documentation as well as the documented source
code for a crash course on good practice when writing 3rd party django modules.

`Read the guide here <http://django-module-crash-course.readthedocs.org/en/latest/>`_

Covered topics
--------------

#. Setting up a working environment
#. Creating a sensible project structure for development
#. Things to keep in mind when developing a stand-alone library
#. Testing and Test Driven Development
#. Documenting the library
#. Packing and deploying a 3rd party library to pypi


